Closes the instance. This method should be called when the instance is no longer needed. Once close is called, the instance can no longer be used.
@override Future<void> close() { this.close(); return super.close(); }